declare abstract class ToolboxPanel {
    title: string;
    icon: string;
    constructor(title: string, icon?: string);
    abstract getUi(): HTMLDivElement;
}

interface MarkerBaseState {
    typeName: string;
    state: MarkerState;
}

declare type ColorSet = string[];
declare type DisplayMode = 'inline' | 'popup';
declare class Settings {
    defaultColor: string;
    defaultFillColor: string;
    defaultStrokeColor: string;
    defaultHighlightColor: string;
    defaultStrokeWidth: number;
    defaultStrokeDasharray: string;
    defaultHighlightOpacity: number;
    defaultFontFamily: string;
    defaultColorSet: ColorSet;
    defaultStrokeWidths: number[];
    defaultStrokeDasharrays: string[];
    defaultOpacitySteps: number[];
    displayMode: DisplayMode;
    defaultFontFamilies: string[];
}

declare type MarkerState = 'new' | 'creating' | 'select' | 'move' | 'resize' | 'rotate';
declare class MarkerBase {
    static typeName: string;
    protected _container: SVGGElement;
    get container(): SVGGElement;
    protected _overlayContainer: HTMLDivElement;
    get overlayContainer(): HTMLDivElement;
    protected _state: MarkerState;
    get state(): MarkerState;
    protected globalSettings: Settings;
    get toolboxPanels(): ToolboxPanel[];
    static title: string;
    /**
     * SVG icon markup
     */
    static icon: string;
    onMarkerCreated: (marker: MarkerBase) => void;
    constructor(container: SVGGElement, overlayContainer: HTMLDivElement, settings: Settings);
    ownsTarget(el: EventTarget): boolean;
    select(): void;
    deselect(): void;
    pointerDown(point: IPoint, target?: EventTarget): void;
    dblClick(point: IPoint, target?: EventTarget): void;
    manipulate(point: IPoint): void;
    pointerUp(point: IPoint): void;
    dispose(): void;
    protected addMarkerVisualToContainer(element: SVGElement): void;
    getState(): MarkerBaseState;
    restoreState(state: MarkerBaseState): void;
}

interface MarkerAreaState {
    markers: MarkerBaseState[];
}

interface IPoint {
    x: number;
    y: number;
}
declare type RenderEventHandler = (dataURL: string, state?: MarkerAreaState) => void;
declare type CloseEventHandler = () => void;
declare class MarkerArea {
    private target;
    private targetRoot;
    private width;
    private height;
    private left;
    private top;
    private markerImage;
    private markerImageHolder;
    private defs;
    private coverDiv;
    private uiDiv;
    private contentDiv;
    private editorCanvas;
    private editingTarget;
    private overlayContainer;
    private logoUI;
    private availableMarkerTypes;
    private toolbar;
    private toolbox;
    private mode;
    private currentMarker?;
    private markers;
    private isDragging;
    private bodyOverflowState;
    private scrollYState;
    private scrollXState;
    private renderEventListeners;
    private closeEventListeners;
    settings: Settings;
    constructor(target: HTMLImageElement);
    private open;
    show(): void;
    render(): Promise<string>;
    close(): void;
    addMarkersToToolbar(...markers: typeof MarkerBase[]): void;
    addRenderEventListener(listener: RenderEventHandler): void;
    removeRenderEventListener(listener: RenderEventHandler): void;
    addCloseEventListener(listener: CloseEventHandler): void;
    removeCloseEventListener(listener: CloseEventHandler): void;
    private setEditingTarget;
    private setTopLeft;
    private initMarkerCanvas;
    private initOverlay;
    private positionMarkerImage;
    private attachEvents;
    /**
     * NOTE:
     *
     * before removing or modifying this method please consider supporting marker.js
     * by visiting https://markerjs.com/#price for details
     *
     * thank you!
     */
    private addLogo;
    private positionLogo;
    private overrideOverflow;
    private restoreOverflow;
    private showUI;
    private closeUI;
    private toolbarButtonClicked;
    private renderClicked;
    getState(): MarkerAreaState;
    restoreState(state: MarkerAreaState): void;
    private addNewMarker;
    private createNewMarker;
    private markerCreated;
    private setCurrentMarker;
    private onPointerDown;
    private onDblClick;
    private onPointerMove;
    private onPointerUp;
    private clientToLocalCoordinates;
    private onWindowResize;
    private positionUI;
}

declare class Activator {
    static key: string;
    static get isLicensed(): boolean;
}

declare class SvgHelper {
    static createDefs(): SVGDefsElement;
    static setAttributes(el: SVGElement, attributes: Array<[string, string]>): void;
    static createRect(width: number | string, height: number | string, attributes?: Array<[string, string]>): SVGRectElement;
    static createLine(x1: number | string, y1: number | string, x2: number | string, y2: number | string, attributes?: Array<[string, string]>): SVGLineElement;
    static createPolygon(points: string, attributes?: Array<[string, string]>): SVGPolygonElement;
    static createCircle(radius: number, attributes?: Array<[string, string]>): SVGCircleElement;
    static createEllipse(rx: number, ry: number, attributes?: Array<[string, string]>): SVGEllipseElement;
    static createGroup(attributes?: Array<[string, string]>): SVGGElement;
    static createTransform(): SVGTransform;
    static createMarker(id: string, orient: string, markerWidth: number | string, markerHeight: number | string, refX: number | string, refY: number | string, markerElement: SVGGraphicsElement): SVGMarkerElement;
    static createText(attributes?: Array<[string, string]>): SVGTextElement;
    static createTSpan(text: string, attributes?: Array<[string, string]>): SVGTSpanElement;
    static createImage(attributes?: Array<[string, string]>): SVGImageElement;
    static createPoint(x: number, y: number): SVGPoint;
}

interface IStyleSettings {
    toolbarBackgroundColor?: string;
    toolbarBackgroundHoverColor?: string;
    toolbarColor?: string;
    toolbarHeight?: number;
    toolboxBackgroundColor?: string;
    toolboxColor?: string;
    toolboxAccentColor?: string;
}

declare class Style {
    static CLASS_PREFIX: string;
    private static classes;
    private static rules;
    private static styleSheet?;
    static settings: IStyleSettings;
    static addClass(styleClass: StyleClass): StyleClass;
    static addRule(styleRule: StyleRule): void;
    private static addStyleSheet;
}
declare class StyleRule {
    selector: string;
    style: string;
    constructor(selector: string, style: string);
}
declare class StyleClass {
    style: string;
    private _localName;
    get name(): string;
    constructor(name: string, style: string);
}

export { Activator, MarkerArea, MarkerBase, Style, StyleClass, SvgHelper };
